@@ -31,7 +31,7 @@ class LineupOptimizer:
             position.positions for position in self._settings.positions))
         self._removed_players = []  # type: List[Player]
         self._search_threshold = 0.8
-        self._min_deviation = 0.06
+        self._min_deviation = 0.0
         self._max_deviation = 0.12
         self.players_from_one_team = {}  # type: Dict[str, int]
         self.players_with_same_position = {}  # type: Dict[str, int]
@@ -47,6 +47,7 @@ class LineupOptimizer:
         self.team_stacks_for_positions = None  # type: Optional[List[str]]
         self.same_team_restrict_positions = None  # type: Optional[Tuple[Tuple[str, str], ...]]
         self.opposing_team_force_positions = None  # type: Optional[Tuple[Tuple[str, str], ...]]
+        self.opposing_teams_max_allowed = 0
         self.total_teams = None  # type: Optional[int]
         self.stacks = []  # type: List[BaseStack]
         self.min_starters = None  # type: Optional[int]
@@ -248,7 +249,7 @@ class LineupOptimizer:
 
     def set_positions_for_same_team(self, *positions_stacks: List[Union[str, Tuple[str, ...]]]):
         warnings.simplefilter('always', DeprecationWarning)
-        warnings.warn('set_positions_for_same_team method will be removed in 3.2, use add_stack instead', DeprecationWarning)
+        warnings.warn('set_positions_for_same_team method will be removed in 3.3, use add_stack instead', DeprecationWarning)
         if positions_stacks and positions_stacks[0] is not None:
             team_stacks = [
                 PositionsStack(stack, max_exposure_per_team=self.teams_exposures) for stack in positions_stacks]
@@ -281,16 +282,22 @@ class LineupOptimizer:
 
     def set_team_stacking(self, stacks: Optional[List[int]], for_positions: Optional[List[str]] = None):
         warnings.simplefilter('always', DeprecationWarning)
-        warnings.warn('set_team_stacking method will be removed in 3.2, use add_stack instead', DeprecationWarning)
+        warnings.warn('set_team_stacking method will be removed in 3.3, use add_stack instead', DeprecationWarning)
         if stacks:
             team_stacks = [TeamStack(stack, for_positions=for_positions, max_exposure_per_team=self.teams_exposures) for stack in stacks]
             for stack in team_stacks:
                 self.add_stack(stack)
 
-    def restrict_positions_for_opposing_team(self, first_team_positions: List[str], second_team_positions: List[str]):
+    def restrict_positions_for_opposing_team(
+            self,
+            first_team_positions: List[str],
+            second_team_positions: List[str],
+            max_allowed: int = 0,
+    ):
         if not self.games:
             raise LineupOptimizerException('Game Info isn\'t specified for players')
         self.opposing_teams_position_restriction = (first_team_positions, second_team_positions)
+        self.opposing_teams_max_allowed = max_allowed
         self.add_new_rule(RestrictPositionsForOpposingTeam)
 
     def restrict_positions_for_same_team(self, *restrict_positions: Tuple[str, str]):
