@@ -1,5 +1,5 @@
-from .importer import *
-from .settings import *
+from pydfs_lineup_optimizer.sites.yahoo.importer import *
+from pydfs_lineup_optimizer.sites.yahoo.settings import *
 
 
 __all__ = [
